@@ -99,7 +99,7 @@ class SimpleRunner(AbstractRunner):
         print('max running date '+str(max(df.index)))
 
         print('loading supervision results')
-        result =self.dbx.local_supervision_npy_overwrite_and_load_array(starting_date= self.starting_date, ending_date = self.ending_date, rebal = s , lower_bound= low_bound, upper_bound = up_bound, local_root_directory= self.local_root_directory, user = self.user, supervision_npy_file_suffix= self.supervision_npy_file_suffix)
+        result =self.dbx.local_supervision_npy_overwrite_and_load_array(starting_date= self.starting_date, ending_date = self.running_date, rebal = s , lower_bound= low_bound, upper_bound = up_bound, local_root_directory= self.local_root_directory, user = self.user, supervision_npy_file_suffix= self.supervision_npy_file_suffix)
         print('supervision results shape')
         print(result.shape)
 
@@ -222,7 +222,8 @@ class SimpleRunner(AbstractRunner):
             )
             tm = tm.set_roll_period(n, s)
 
-        eval_slice, test_slice = tm.unroll()
+        eval_slice, test_slice, predictors, tt, tt_true = tm.unroll()
+
         dates_eval_slice, dates_test_slice = df.index[eval_slice], df.index[test_slice]
 
         state = resuming_state.ModelState(
@@ -242,7 +243,7 @@ class SimpleRunner(AbstractRunner):
 
         recordings_df, activations_df = tm.recorder.get_all_recordings()
         print('recordings '+str(list(recordings_df.columns)))
-        print('activatiions ' + str(list(activations_df.columns)))
+        print('activations ' + str(list(activations_df.columns)))
 
         # tm.y_test[tm.t:] = tm.sub_predict(tm.X[tm.t:])
         df_ret = df.fillna(method='bfill').pct_change().fillna(0).copy()
@@ -257,7 +258,7 @@ class SimpleRunner(AbstractRunner):
             self.dbx.uploadFileToDropbox(filename=savingKey+'_model.torch', dropbox_subfolder = '', fullpath=self.local_root_directory+savingKey+'_model.torch')
             self.dbx.uploadFileToDropbox(filename=savingKey+'_py.obj', dropbox_subfolder = '', fullpath=self.local_root_directory+savingKey+'_py.obj')
 
-        saver.saveResults(savingKey, portfolio, weight_mat, recordings_df, activations_df)
+        saver.saveResults(savingKey, portfolio, weight_mat, recordings_df, activations_df, last_predicted_weights)
         print('saved '+ savingKey)
         return  last_predicted_weights
 
