@@ -648,7 +648,7 @@ def rolling_forward_looking_allocation(f, X, n=252, s=63, ret=True, drift=True,
 
     return portfolio, w_mat
 
-def rolling_allocation(f, X, n=252, s=63, ret=True, drift=True, **kwargs):
+def rolling_allocation(f, X, n=252, s=63, ret=True, drift=True, filtering_threshold = 0.7, **kwargs):
     r""" Roll an algorithm of portfolio allocation.
 
     Notes
@@ -703,7 +703,7 @@ def rolling_allocation(f, X, n=252, s=63, ret=True, drift=True, **kwargs):
 
     def allocation_process(series):
         # True if less than 50% of obs. are constant
-        return series.value_counts(dropna=False).max() < 0.5 * n
+        return series.value_counts(dropna=False).max() < filtering_threshold * n
 
     for slice_n, slice_s in roll():
         # Select X
